/**
 * Class representing the Brand API endpoints.
 * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/}
 */
export class Brand extends Client {
    constructor(options: any);
    jsonAPINames: string[];
    /**
     * List all brands.
     * @returns {Promise<{response: object, result: Array<object>}>} The list of brands.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#list-brands}
     * @example const brands = await client.brands.list();
     */
    list(): Promise<{
        response: object;
        result: Array<object>;
    }>;
    /**
     * Show a specific brand by ID.
     * @param {number} brandId - The ID of the brand.
     * @returns {Promise<{response: object, result: object}>} The brand details.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#show-a-brand}
     * @example const brand = await client.brands.show(47);
     */
    show(brandId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Create a new brand.
     * @param {object} brand - The brand data.
     * @returns {Promise<{response: object, result: object}>} The created brand details.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#create-brand}
     * @example const newBrand = await client.brands.create({name: "Brand 1", subdomain: "Brand1"});
     */
    create(brand: object): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Update an existing brand.
     * @param {object} brand - The updated brand data.
     * @param {number} brandId - The ID of the brand to update.
     * @returns {Promise<{response: object, result: object}>} The updated brand details.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#update-a-brand}
     * @example const updatedBrand = await client.brands.update({name: "Updated Brand"}, 47);
     */
    update(brand: object, brandId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Delete a brand.
     * @param {number} brandId - The ID of the brand to delete.
     * @returns {Promise<object>} The deletion status.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#delete-a-brand}
     * @example await client.brands.delete(47);
     */
    delete(brandId: number): Promise<object>;
    /**
     * Check host mapping validity for a given subdomain and host mapping.
     * @param {string} hostMapping - The host mapping to check.
     * @param {string} subdomain - The subdomain to check.
     * @returns {Promise<{response: object, result: object}>} The check result.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#check-host-mapping-validity}
     * @example await client.brands.checkHostMapping("brand1.com", "brand1");
     */
    checkHostMapping(hostMapping: string, subdomain: string): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Check host mapping validity for an existing brand.
     * @param {number} brandId - The ID of the brand to check.
     * @returns {Promise<{response: object, result: object}>} The check result.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/account-configuration/brands/#check-host-mapping-validity-for-an-existing-brand}
     * @example await client.brands.checkHostMappingForExistingBrand(47);
     */
    checkHostMappingForExistingBrand(brandId: number): Promise<{
        response: object;
        result: object;
    }>;
}
import { Client } from "../client";
