/**
 * Client for interacting with the Zendesk User Identities API.
 * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/}
 */
export class UserIdentities extends Client {
    constructor(options: any);
    jsonAPINames: string[];
    /**
     * List all identities for a given user.
     * @param {number} userId - The ID of the user.
     * @returns {Promise<object[]>} A list of user identities.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#list-identities}
     * @example const identities = await client.useridentities.list(12345);
     */
    list(userId: number): Promise<object[]>;
    /**
     * Show a specific identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to show.
     * @returns {Promise<{response: object, result: object}>} The user identity details.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#show-identity}
     * @example const identity = await client.useridentities.show(12345, 67890);
     */
    show(userId: number, userIdentityId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Create a new identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {object} userIdentity - The user identity details to create.
     * @returns {Promise<{response: object, result: object}>} The created user identity.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#create-identity}
     * @example const newIdentity = await client.useridentities.create(12345, {type: 'email', value: 'test@example.com'});
     */
    create(userId: number, userIdentity: object): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Update a specific identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to update.
     * @param {object} identity - The updated identity details.
     * @returns {Promise<{response: object, result: object}>} The updated user identity.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#update-identity}
     * @example const updatedIdentity = await client.useridentities.update(12345, 67890, {verified: true});
     */
    update(userId: number, userIdentityId: number, identity: object): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Make a specific identity the primary identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to make primary.
     * @returns {Promise<{response: object, result: object}>} The updated user identity.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#make-identity-primary}
     * @example await client.useridentities.makePrimary(12345, 67890);
     */
    makePrimary(userId: number, userIdentityId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Verify a specific identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to verify.
     * @returns {Promise<{response: object, result: object}>} The verified user identity.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#verify-identity}
     * @example await client.useridentities.verify(12345, 67890);
     */
    verify(userId: number, userIdentityId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Request verification for a specific identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to request verification for.
     * @returns {Promise<{response: object, result: object}>} The user identity verification request details.
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#request-user-verification}
     * @example await client.useridentities.requestVerification(12345, 67890);
     */
    requestVerification(userId: number, userIdentityId: number): Promise<{
        response: object;
        result: object;
    }>;
    /**
     * Delete a specific identity for a given user.
     * @param {number} userId - The ID of the user.
     * @param {number} userIdentityId - The ID of the user identity to delete.
     * @returns {Promise<void>}
     * @throws {Error} Throws an error if the request fails.
     * @see {@link https://developer.zendesk.com/api-reference/ticketing/users/user_identities/#delete-identity}
     * @example await client.useridentities.delete(12345, 67890);
     */
    delete(userId: number, userIdentityId: number): Promise<void>;
}
import { Client } from "../client";
